@@ -3,7 +3,7 @@
 #include <QFile>
 
 AonLicenseWindow::AonLicenseWindow(QWidget *parent) :
-    QDialog(parent),
+    DialogWindow(parent),
     ui(new Ui::AonLicenseWindow)
 {
     ui->setupUi(this);
