@@ -102,16 +102,49 @@ QDataStream &operator>>(QDataStream &in, Weapon &weapon)
     return in;
 }
 
+Q_DECLARE_METATYPE(Armor)
+Q_DECLARE_METATYPE(Armor*)
+Q_DECLARE_METATYPE(QList<Armor*>)
+QScriptValue ArmorToScriptValue(QScriptEngine *engine, Armor* const &in)
+{ return engine->newQObject(in); }
+
+void ArmorFromScriptValue(const QScriptValue &object, Armor* &out)
+{ out = qobject_cast<Armor*>(object.toQObject()); }
+
+QDataStream &operator<<(QDataStream &out, const Armor &armor)
+{
+    out << armor.Name << armor.Description
+        << armor.Properties;
+    return out;
+}
+
+QDataStream &operator>>(QDataStream &in, Armor &armor)
+{
+    in >> armor.Name >> armor.Description
+       >> armor.Properties;
+    return in;
+}
+
 Q_DECLARE_METATYPE(KaiDiscipline)
+Q_DECLARE_METATYPE(KaiDiscipline*)
+QScriptValue KaiDisciplineToScriptValue(QScriptEngine *engine, KaiDiscipline* const &in)
+{ return engine->newQObject(in); }
+
+void KaiDisciplineFromScriptValue(const QScriptValue &object, KaiDiscipline* &out)
+{ out = qobject_cast<KaiDiscipline*>(object.toQObject()); }
+
+
 QDataStream &operator<<(QDataStream &out, const KaiDiscipline &d)
 {
-    out << d.Name << d.CombatSkillDelta;
+    out << d.Name << d.CombatSkillDelta << d.Serie << d.HelpText << d.GetIsActive();
     return out;
 }
 
 QDataStream &operator>>(QDataStream &in, KaiDiscipline &d)
 {
-    in >> d.Name >> d.CombatSkillDelta;
+    bool active = false;
+    in >> d.Name >> d.CombatSkillDelta >> d.Serie >> d.HelpText >> active;
+    d.SetIsActive(active);
     return in;
 }
 
@@ -119,7 +152,7 @@ Q_DECLARE_METATYPE(Weaponskill)
 QDataStream &operator<<(QDataStream &out, const Weaponskill &d)
 {
     out << d.Name << d.CombatSkillDelta
-        << d.Weapon;
+        << d.Weapon << d.Serie << d.HelpText;
     return out;
 }
 
@@ -160,6 +193,8 @@ BookWindow::BookWindow(QWidget *parent) :
     qRegisterMetaType<Item>("Item");
     qRegisterMetaTypeStreamOperators<Weapon>("Weapon");
     qRegisterMetaType<Weapon>("Weapon");
+    qRegisterMetaTypeStreamOperators<Armor>("Armor");
+    qRegisterMetaType<Armor>("Armor");
     qRegisterMetaTypeStreamOperators<KaiDiscipline>("KaiDiscipline");
     qRegisterMetaType<KaiDiscipline>("KaiDiscipline");
     qRegisterMetaTypeStreamOperators<Weaponskill>("Weaponskill");
@@ -188,11 +223,9 @@ BookWindow::BookWindow(QWidget *parent) :
     ui->line->setVisible(false);
 #endif
 
-#if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
 #ifdef QT_NO_DEBUG
     ui->spinSection->setVisible(false);
     ui->pbnGo->setVisible(false);
-#endif
 #endif
 
     ui->webView->setContextMenuPolicy(Qt::NoContextMenu);
@@ -239,9 +272,14 @@ BookWindow::BookWindow(QWidget *parent) :
 
     m_Loaded = false;
 
+    // Register script types:
     qScriptRegisterMetaType(&m_Engine, ChoiceToScriptValue, ChoiceFromScriptValue);
     qScriptRegisterMetaType(&m_Engine, ItemToScriptValue, ItemFromScriptValue);
     qScriptRegisterMetaType(&m_Engine, WeaponToScriptValue, WeaponFromScriptValue);
+    qScriptRegisterMetaType(&m_Engine, ArmorToScriptValue, ArmorFromScriptValue);
+    qScriptRegisterMetaType(&m_Engine, KaiDisciplineToScriptValue, KaiDisciplineFromScriptValue);
+
+    qScriptRegisterSequenceMetaType< QList<Armor*> >(&m_Engine);
 }
 
 void BookWindow::Init()
@@ -957,6 +995,20 @@ bool BookWindow::Load(QString filename)
             // the CanBeEquipped property
             if ((i->GetIsArmor() || i->GetIsWeapon()) && !i->HasProperty("CanBeEquipped"))
                 i->SetCanBeEquipped(true);
+
+            // Fix armor class:
+            if (i->GetIsArmor()){
+                if (!QString::compare(i->GetName(), "Chainmail Waistcoat", Qt::CaseInsensitive))
+                    i->SetArmorClass(Armor::Body);
+                else if (!QString::compare(i->GetName(), "Padded Leather Waistcoat", Qt::CaseInsensitive))
+                    i->SetArmorClass(Armor::Body);
+                else if (!QString::compare(i->GetName(), "Silver Helm", Qt::CaseInsensitive))
+                    i->SetArmorClass(Armor::Head);
+                else if (!QString::compare(i->GetName(), "Shield", Qt::CaseInsensitive)){
+                    i->SetArmorClass(Armor::Shield);
+                    i->SetHands(1);
+                }
+            }
             m_Player->Items.append(i);
         }else{
             var = settings.value("weapon");
@@ -990,14 +1042,18 @@ bool BookWindow::Load(QString filename)
                 }
 
                 // Fix Sommerswerd (in book 2 the CombatskillDelta was wrong):
-                if (w->GetName() == "Sommerswerd" && w->GetCombatskillDelta() == 10){
-                    w->Classes().clear();
-                    w->AddClass(Weapon::Sword);
-                    w->AddClass(Weapon::Broadsword);
-                    w->AddClass(Weapon::ShortSword);
-                    w->SetCombatskillDelta(8);
-                }
+                if (w->GetName() == "Sommerswerd"){
+                    w->SetDescription("");
+                    w->SetIsSpecial(true);
 
+                    if (w->GetCombatskillDelta() == 10){
+                        w->Classes().clear();
+                        w->AddClass(Weapon::Sword);
+                        w->AddClass(Weapon::Broadsword);
+                        w->AddClass(Weapon::ShortSword);
+                        w->SetCombatskillDelta(8);
+                    }
+                }
                 m_Player->Items.append(w);
             }
         }
@@ -1083,6 +1139,9 @@ bool BookWindow::Load(QString filename)
     }
     settings.endArray();
 
+    //////////////////////////////////////////////////////////////////////////////
+    // Fixes for bugs and anomalous situations:
+    //////////////////////////////////////////////////////////////////////////////
     // Fix for discipline bug in book 6 (the Kai disciplines were removed):
     if (m_Book->GetSerie() == Book::Magnakai){
         if(!m_Player->HasDiscipline("Camouflage")){
@@ -1131,7 +1190,7 @@ bool BookWindow::Load(QString filename)
     if (m_Player->HasDiscipline("Psi-surge") && !m_Player->HasDiscipline("Mindblast")){
         Mindblast* m = new Mindblast(m_Player);
         m->Serie = 0; // To avoid counting it in GetDisciplineCount
-        m->Active = false;
+        m->SetIsActive(false);
         m_Player->KaiDisciplines.append(m);
     }
 
@@ -1148,6 +1207,27 @@ bool BookWindow::Load(QString filename)
             d->Serie = 0;
     }
 
+    // Check player hands and armor:
+    int hands = m_Player->GetHands();
+    foreach (Item* i, m_Player->Items){
+        if (i->GetIsEquipped()){
+            if (i->GetIsArmor()){
+                i->Unequip();
+                if (m_Player->CanEquipArmor((Armor*)i, NULL)){
+                    i->Equip();
+                    hands -= i->GetHands();
+                }
+            }else if(i->GetIsWeapon()){
+                hands -= i->GetHands();
+            }
+
+            if(hands < 0 && i->GetHands() > 0){
+                i->Unequip();
+                hands += i->GetHands();
+            }
+        }
+    }
+
     m_Loaded = true;
     return true;
 }
