@@ -1,7 +1,6 @@
 #ifndef CHOOSEITEMWINDOW_H
 #define CHOOSEITEMWINDOW_H
 
-#include <QDialog>
 #include "controls/dialogwindow.h"
 #include "core/player.h"
 
@@ -25,7 +24,8 @@ public:
     explicit ChooseItemWindow(QWidget *parent = 0, Player* player=0, int mode=ChooseMeal);
     ~ChooseItemWindow();
 
-    Item* SelectedItem() { return m_Selected; }
+    Item* SelectedItem() { return m_Selected; }    
+    void SetMessage(QString message);
 
 private:
     Ui::ChooseItemWindow *ui;
