@@ -72,7 +72,23 @@ Choice* Section::GetChoiceFromTarget(int target)
 
 Choice* Section::GetChoice(int index)
 {
-    return Choices.at(index);
+    if (index < Choices.count())
+        return Choices.at(index);
+    return NULL;
+}
+
+void Section::EnableChoice(int index)
+{
+    Choice* c = GetChoice(index);
+    if (c)
+        c->SetEnabled(true);
+}
+
+void Section::DisableChoice(int index)
+{
+    Choice* c = GetChoice(index);
+    if (c)
+        c->SetEnabled(false);
 }
 
 int Section::UserChoicesCount()
