@@ -128,6 +128,48 @@ void Item::SetArmorClass(QString value)
     SetProperty("ArmorClass", QString::number(aClass));
 }
 
+QList<int> Item::GetWeaponClasses()
+{
+    QList<int> res;
+    QStringList str = GetProperty("Classes").split(";", QString::SkipEmptyParts);
+    foreach (QString s, str){
+        res.append(s.toInt());
+    }
+    return res;
+}
+
+void Item::AddWeaponClass(int iClass)
+{
+    if (iClass != Weapon::None){
+        QString str = GetProperty("Classes");
+        str.append(QString(";%1").arg(iClass));
+        SetProperty("Classes", str);
+    }
+}
+
+void Item::AddWeaponClass(QString value)
+{
+    AddWeaponClass(Weapon::GetClass(value));
+}
+
+bool Item::HasWeaponClass(QString value)
+{
+    return GetWeaponClasses().contains(Weapon::GetClass(value));
+}
+
+bool Item::HasWeaponClass(int value)
+{
+    return GetWeaponClasses().contains(value);
+}
+
+int Item::GetTotalSize()
+{
+    if (GetQuantity())
+        return GetSize() * GetQuantity();
+    return GetSize();
+}
+
+
 Weapon::Weapon(QObject *parent) :
     Item(parent)
 {
@@ -169,7 +211,8 @@ int Weapon::GetClass(QString wclass)
 int Weapon::GetHands()
 {
     QList<int> classes = Classes();
-    if (classes.contains(Spear) || classes.contains(Broadsword) ||
+    if (classes.contains(Spear) ||
+        (classes.contains(Broadsword) && !classes.contains(Sword)) ||
         classes.contains(Quarterstaff))
         return 2;
     return 1;
@@ -177,9 +220,12 @@ int Weapon::GetHands()
 
 void Weapon::AddClass(int iClass)
 {
-    QString str = GetProperty("Classes");
-    str.append(QString(";%1").arg(iClass));
-    SetProperty("Classes", str);
+    AddWeaponClass(iClass);
+}
+
+void Weapon::AddClass(QString value)
+{
+    AddWeaponClass(value);
 }
 
 bool Weapon::HasClass(QString value)
@@ -194,12 +240,7 @@ bool Weapon::HasClass(int value)
 
 QList<int> Weapon::Classes()
 {
-    QList<int> res;
-    QStringList str = GetProperty("Classes").split(";", QString::SkipEmptyParts);
-    foreach (QString s, str){
-        res.append(s.toInt());
-    }
-    return res;
+    return GetWeaponClasses();
 }
 
 QString Weapon::ClassDescription(int Class)
@@ -291,3 +332,8 @@ int Armor::GetHands()
         return 1;
     return 0;
 }
+
+bool Armor::HasClass(QString value)
+{
+    return GetArmorClass() == Armor::GetClass(value);
+}
