@@ -45,6 +45,10 @@ public:
     static void ClearCircles();
 };
 
+//!  Describes a generic discipline
+/*!
+
+*/
 
 class KaiDiscipline : public QObject
 {
@@ -54,8 +58,6 @@ public:
     KaiDiscipline(const KaiDiscipline& discipline);
 
     int Serie;
-    QList<int> Circles;
-    bool Active;
     QString Name;
     QString HelpText;
     int CombatSkillDelta;
@@ -63,7 +65,20 @@ public:
     virtual QString Description();
 
     virtual QString ToString();
-    virtual void FromString(QString string);
+    virtual void FromString(QString string);       
+
+private:
+    bool m_Active;
+
+public slots:
+    /** Returns the discipline combat skill bonus */
+    int GetCombatSkillDelta() const { return CombatSkillDelta; }
+    /** Sets the discipline combat skill bonus */
+    void SetCombatSkillDelta(int value) { CombatSkillDelta = value;}
+    /** Returns true if the discipline is active*/
+    bool GetIsActive() const { return m_Active; }
+    /** Sets if the discipline is active*/
+    void SetIsActive(bool value) { m_Active = value;}
 };
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////
