@@ -36,7 +36,7 @@ QList<Weapon*> Player::Weapons(bool includeSpecial)
 {
     QList<Weapon*> res;
     foreach (Item* i, Items){
-        if (i->GetIsWeapon() && (!includeSpecial || !i->GetIsSpecial()))
+        if (i->GetIsWeapon() && ((!includeSpecial && !i->GetIsSpecial()) || includeSpecial))
             res.append((Weapon*)i);
     }
     return res;
@@ -150,7 +150,7 @@ int Player::GetCombatSkill(Enemy* enemy, QStringList* description)
     }
 
     foreach (KaiDiscipline* d, KaiDisciplines){
-        if (d->Active){
+        if (d->GetIsActive()){
             // Count CombatSkillDelta only versus enemies:
             if (enemy != NULL && !enemy->DisciplineImmunities.contains(d->Name)){
                 result += d->CombatSkillDelta;
@@ -332,7 +332,7 @@ bool Player::IsDisciplineActive(QString name)
 {
     KaiDiscipline* d = GetDiscipline(name);
     if (d != NULL)
-        return d->Active;
+        return d->GetIsActive();
     return false;
 }
 
@@ -748,6 +748,15 @@ QList<Armor*> Player::GetEquippedArmors()
     return res;
 }
 
+Armor* Player::GetEquippedShield()
+{
+    foreach (Item* i, Items){
+        if (i->GetIsArmor() && i->GetArmorClass() == Armor::Shield && i->GetIsEquipped())
+            return (Armor*)i;
+    }
+    return NULL;
+}
+
 QStringList Player::GetAllItems()
 {
     QStringList res;
@@ -1022,6 +1031,42 @@ void Player::AppendNotesLine(QString value)
     SetNotes(value);
 }
 
+bool Player::CanEquipArmor(Armor* armor, QString* error)
+{
+    if (armor->GetIsEquipped()){
+        return true;
+    }else{
+        if (armor->GetClass() == Armor::Shield && !GetCanUseShield()){
+            if (error)
+                *error = "You cannot equip a shield now.";
+            return false;
+        }
+
+        // Che armors of the same class:
+        QList<Armor*> equipped = GetEquippedArmors();
+        foreach (Armor* a, equipped){
+            if (a->GetArmorClass() == armor->GetClass()){
+                if (error)
+                    *error = "You cannot equip this armor now.";
+                return false;
+            }
+        }
+
+        // Check free hands (only for shields)
+        if (armor->GetClass() == Armor::Shield){
+            if (GetFreeHands() >= 1){
+                return true;
+            }else{
+                if (error)
+                    *error = "You cannot equip a shield now.";
+                return false;
+            }
+        }else
+            return true;
+    }
+    return true;
+}
+
 void Player::Dump()
 {
     qDebug() << "Base properties:";
@@ -1034,6 +1079,7 @@ void Player::Dump()
     }
     qDebug() << "Items:";
     foreach(Item* i, Items){
-        qDebug() << "  " << i->GetUUID() << i->GetName() << "Special:" << i->GetIsSpecial();
+        qDebug() << "  " << i->GetUUID() << i->GetName() << "Special:" << i->GetIsSpecial()
+                 << "Size:" << i->GetSize();
     }
 }
