@@ -44,12 +44,14 @@ public:
     QHash<QString, QString> Properties;
     void CheckEndurance();
     void Dump();
-    KaiDiscipline* GetDiscipline(QString name);
     /** Returns the serie of the player (maximum serie of the disciplines)*/
     int GetSerie();
 
     int GetBaseEndurance(QStringList*);
     QStringList GetBaseEnduranceDescription();
+    bool CanEquipArmor(Armor* armor, QString* error);
+    /** Returns a list of armors currently equipped */
+    QList<Armor*> GetEquippedArmors();
 
 private:
     bool m_Backpack;
@@ -63,6 +65,8 @@ public slots:
      *  counted.
     */
     void RemoveDisciplines();
+    /** Return the given Kai Discipline */
+    KaiDiscipline* GetDiscipline(QString name);
 
     /** Return true if the player is dead */
     bool IsDead();
@@ -203,9 +207,9 @@ public slots:
     /** Returns true if the player has the given weapon */
     bool HasWeapon(QString name);
     /** Returns true if the player has at least one weapon of the given class */
-    bool HasWeaponOfClass(QString wClass);
-    /** Returns a list of armors currently equipped */
-    QList<Armor*> GetEquippedArmors();
+    bool HasWeaponOfClass(QString wClass);  
+    /** Returns the shield currently equipped (or NULL)*/
+    Armor* GetEquippedShield();
     /** Returns the weapon with the given name (or NULL) */
     Weapon* GetWeapon(QString name);
 
