@@ -18,7 +18,7 @@ public:
         Load,
         MainMenu,
         Quit,
-        Restart,
+        Restart
     };
 
     explicit EndWindow(QWidget *parent = 0);
