@@ -115,20 +115,20 @@ void FightWindow::UpdateData()
             items.insert(0, "None");
             KaiDiscipline* mindBlast = m_Player->GetDiscipline("Mindblast");
             KaiDiscipline* psiSurge = m_Player->GetDiscipline("Psi-surge");
-            if (psiSurge->Active && !items.contains("Psi-surge"))
-                psiSurge->Active = false;
-            if (mindBlast->Active && !items.contains("Mindblast"))
-                mindBlast->Active = false;
+            if (psiSurge->GetIsActive() && !items.contains("Psi-surge"))
+                psiSurge->SetIsActive(false);
+            if (mindBlast->GetIsActive() && !items.contains("Mindblast"))
+                mindBlast->SetIsActive(false);
 
-            if (psiSurge->Active && m_Player->Endurance <= 6){
-                psiSurge->Active = false;
+            if (psiSurge->GetIsActive() && m_Player->Endurance <= 6){
+                psiSurge->SetIsActive(false);
                 ui->cmbDiscipline->setEnabled(false);
             }
 
             ui->cmbDiscipline->addItems(items);
-            if (psiSurge->Active)
+            if (psiSurge->GetIsActive())
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("Psi-surge"));
-            else if (mindBlast->Active)
+            else if (mindBlast->GetIsActive())
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("Mindblast"));
             else if (items.contains("None"))
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("None"));
@@ -261,7 +261,7 @@ void FightWindow::Evaluate(int number)
     }
 
     KaiDiscipline* psiSurge = m_Player->GetDiscipline("Psi-surge");
-    if (psiSurge && psiSurge->Active &&m_Player->GetEndurance() >= 6){
+    if (psiSurge && psiSurge->GetIsActive() &&m_Player->GetEndurance() >= 6){
         if (m_Player->GetDisciplineCount() >= 9)
             m_PlayerDamage += 1;
         else
@@ -392,24 +392,24 @@ void FightWindow::DisciplineChangedSlot(int index)
         if (discipline == "None"){
             KaiDiscipline* d = m_Player->GetDiscipline("Mindblast");
             if (d)
-                d->Active = false;
+                d->SetIsActive(false);
             d = m_Player->GetDiscipline("Psi-surge");
             if (d)
-                d->Active = false;
+                d->SetIsActive(false);
         }else if (discipline == "Mindblast"){
             KaiDiscipline* d = m_Player->GetDiscipline("Mindblast");
             if (d)
-                d->Active = true;
+                d->SetIsActive(true);
             d = m_Player->GetDiscipline("Psi-surge");
             if (d)
-                d->Active = false;
+                d->SetIsActive(false);
         }else if (discipline == "Psi-surge"){
             KaiDiscipline* d = m_Player->GetDiscipline("Mindblast");
             if (d)
-                d->Active = false;
+                d->SetIsActive(false);
             d = m_Player->GetDiscipline("Psi-surge");
             if (d)
-                d->Active = true;
+                d->SetIsActive(true);
         }
         UpdateData();
     }
