@@ -5,10 +5,12 @@
 #include <QColorDialog>
 
 SettingsWindow::SettingsWindow(QWidget *parent) :
-    QDialog(parent),
+    DialogWindow(parent),
     ui(new Ui::SettingsWindow)
 {
     ui->setupUi(this);
+    SetCanClose(true);
+
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation);
     setAttribute(Qt::WA_Maemo5StackedWindow);
